@@ -45,55 +45,6 @@ class Dataset(SirenComponent):
 
         return siren_to_entity(SirenAdapterResponse(response).to_siren())
 
-    def get_dataset_partitions(self, id=None, name=None, package_id=None, package_name=None):
-        """
-        Retrieves the list of available partitions for a given dataset
-
-        :param str id: The id of the dataset.
-        :param str name: The name of the dataset.
-        :param str package_id: The id of the package to which this dataset belongs.
-                            Either this or package name is required if dataset is being looked up by name.
-        :param str package_name: The name of the package to which this dataset belongs.
-                            Either this or package id is required if dataset is being looked up by name.
-
-        :returns: The dataset partitions in JSON format ( e.g. { ‘location’: [‘us’, ‘eu’], ...} )
-        :rtype: dict
-
-        - **Sample**
-
-        .. code-block:: python
-
-                # Look up by dataset id
-                dataset = client.get_dataset_partitions('my_dataset_id')
-                # or equivalent
-                dataset = client.get_dataset_partitions(id='my_dataset_id')
-
-                # Look up by dataset name
-
-                # If package id is known
-                dataset = client.get_dataset_partitions(name='my_dataset', package_id='my_package_id')
-
-                # if package name is known
-                dataset = client.get_dataset_partitions(name='my_dataset', package_name='my_package')
-        """
-        if name and (package_name or package_id):
-            warnings.warn(
-                'Getting a dataset by name, and package name or package ID'
-                'will be deprecated in future. Short-code will replace getting by name or ID.',
-                PendingDeprecationWarning
-            )
-
-            id = self._get_dataset_id_by_name(
-                dataset_name=name,
-                package_id=package_id,
-                package_name=package_name
-            )
-
-        ds = self.get_dataset(id=id)
-        response = ds.partitions()
-
-        return response
-
     def get_dataset(self, id=None, name=None, package_id=None, package_name=None,
             dataset_short_code=None, organisation_short_code=None):
         """
@@ -137,6 +88,36 @@ class Dataset(SirenComponent):
                 # if package name is known
                 dataset = client.get_dataset(name='my_dataset', package_name='my_package')
         """
+
+        warnings.warn(
+            'This method is deprecated and is scheduled for removal in '
+            'dli=1.13.0. '
+            '\nTo get a dataset, please use the alternate calls:'
+            '\n'
+            '\n    import dli'
+            '\n    client = dli.connect()'
+            '\n    dataset = client.datasets.get(<dataset shortcode>, Optional:<organisation_short_code>)'
+            '\n'
+            '\nor:'
+            '\n'
+            '\n    import dli'
+            '\n    client = dli.connect()'
+            '\n'
+            '\n    # When you do not know the dataset short code and want to search,'
+            '\n    # then there may be multiple matches returned.'
+            '\n    # Return type: OrderedDict[id: str, DatasetModel]'
+            '\n    datasets = client.datasets(search_term=["name=<dataset_name>"])'
+            '\n'
+            '\nWhen you have found your dataset, then you can perform operations on the '
+            'dataset such as:'
+            '\n'
+            '\n    dataset.partitions()'
+            '\n'
+            '\nFor more details please refer to '
+            'https://supportlibrary.ihsmarkit.com/display/DLSL/Using+a+Dataset',
+            PendingDeprecationWarning
+        )
+
         if dataset_short_code:
             response = self.session.get(
                 dataset_urls.v2_by_short_code.format(
@@ -151,14 +132,6 @@ class Dataset(SirenComponent):
                             "with the organisation_short_code.")
 
         else:
-            warnings.warn(
-                'Getting a dataset by id or name with package name or package ID '
-                'will be deprecated in future. Short codes should be used instead - '
-                'please use dataset_short_code and organisation_short_code '
-                'key arguments.',
-                PendingDeprecationWarning
-            )
-
             if not id and name and (package_name or package_id):
                 id = self._get_dataset_id_by_name(
                     dataset_name=name,
@@ -182,12 +155,11 @@ class Dataset(SirenComponent):
                 dataset_urls.v2_by_id.format(id=id)
             )
 
-        return self.Dataset._from_v2_response(response.json())
+        return self.DatasetFactory._from_v2_response(response.json())
 
     def _get_dataset_id_by_name(self, package_id=None,
                                 dataset_name=None,
                                 package_name=None):
-
         if dataset_name and package_name:
             params = {"name": package_name}
 
@@ -234,7 +206,7 @@ class Dataset(SirenComponent):
             },
         ).json()
 
-        return self.Dataset._from_v2_response(result)
+        return self.DatasetFactory._from_v2_response(result)
 
     def edit_dataset(
         self,
@@ -256,7 +228,7 @@ class Dataset(SirenComponent):
         :keyword str name: Optional. A descriptive name of a dataset. It should be unique within the package.
         :keyword str description: Optional. A short description of a package.
         :keyword str content_type: Optional. A way for the data steward to classify the type of data in the dataset
-                                (e.g. pricing).
+                                (e.g. Structured or Unstructured).
         :keyword str data_format: Optional. The format of the data: `CSV`, `IMAGE`, `JSON`, `PARQUET`, `TXT`, `TSV`, XML`, `Other`.
         :keyword str publishing_frequency: Optional. The internal on which data is published. Possible values are: `Hourly`,
                                         `Daily`, `Weekday`, `Weekly`, `Monthly`, `Quarterly`, `Yearly`, `Not Specified`.
@@ -315,7 +287,7 @@ class Dataset(SirenComponent):
             }
         ).json()
 
-        return self.Dataset._from_v2_response(result)
+        return self.DatasetFactory._from_v2_response(result)
 
     def delete_dataset(self, dataset_id):
         """
@@ -364,6 +336,7 @@ class Dataset(SirenComponent):
                     count=10
                 )
         """
+
         ensure_count_is_valid(count)
 
         params = {
