@@ -2,7 +2,7 @@
 # Copyright (C) 2020 IHS Markit.
 # All Rights Reserved
 #
-from dli.client.components import SirenComponent
+from dli.client.components import SirenComponent, SirenAdapterResponse
 from dli.client.utils import ensure_count_is_valid
 from dli.client.components.urls import me_urls
 
@@ -38,7 +38,7 @@ class Me(SirenComponent):
             me_urls.my_packages, params={'page_size': count}
         )
 
-        return response.to_many_siren('package')
+        return SirenAdapterResponse(response).to_many_siren('package')
 
     def get_my_consumed_packages(self, count=100):
         """
@@ -62,7 +62,7 @@ class Me(SirenComponent):
             me_urls.consumed_packages, params={'page_size': count}
         )
 
-        return response.to_many_siren('access_request')
+        return SirenAdapterResponse(response).to_many_siren('access_request')
 
     def get_my_accounts(self):
         """
@@ -79,4 +79,4 @@ class Me(SirenComponent):
 
         """
         response = self.session.get(me_urls.my_accounts)
-        return response.to_many_siren('')
+        return SirenAdapterResponse(response).to_many_siren('')
