@@ -105,7 +105,7 @@ class Package(SirenComponent):
             params={'page_size': count}
         )
 
-        return self.Dataset._from_v2_list_response(response.json())
+        return self.DatasetFactory._from_v2_list_response(response.json())
 
 
     def register_package(
@@ -247,10 +247,11 @@ class Package(SirenComponent):
                 }
             }
 
-            a = self.session.post(
+            json = self.session.post(
                 package_urls.v2_package_index, json=payload
             ).json()
-            return self._Package(a)
+
+            return self._Package(json)
         else:
             payload = {
                 "name": name,
@@ -279,14 +280,14 @@ class Package(SirenComponent):
 
             payload = {k: v for k, v in payload.items() if v is not None}
 
-            if payload["internalData"] == None:
+            if payload["internalData"] is None:
                 payload["internalData"] = 'No'
 
-            result = self.session.post(
+            json = self.session.post(
                 package_urls.package_index, json=payload
-            )
-            return self._Package._from_v1_response_to_v2(result.json())
+            ).json()
 
+            return self._Package._from_v1_response_to_v2(json)
 
     def edit_package(
         self,
@@ -370,7 +371,11 @@ class Package(SirenComponent):
         package = self._get_package(package_id=package_id)
         package_as_dict = to_camel_cased_dict(package.__dict__)
 
-        # clean the package dict with fields that aren't known to us
+        # clean the package dict with fields that aren't known to us.
+        # This is needed to make us less brittle to changes such as DL-4933
+        # where the Catalogue team are returning new fields on the GET
+        # endpoint that are read-only and such `organisation_short_code` which
+        # will fail validation if passed to the PUT endpoint.
         for key in list(package_as_dict.keys()):
             if key not in Package._KNOWN_FIELDS:
                 del package_as_dict[key]
@@ -379,10 +384,11 @@ class Package(SirenComponent):
         #v2 also misses 'internalData'
         package_as_dict.update({'internalData': 'No'})
 
-        result = self.session.put(
+        json = self.session.put(
             package_urls.package_edit.format(id=package_id), json=package_as_dict
-        )
-        return self._Package._from_v1_response_to_v2(result.json())
+        ).json()
+
+        return self._Package._from_v1_response_to_v2(json)
 
     def delete_package(self, package_id):
         """
