@@ -20,6 +20,7 @@ class dataset_urls:
     v2_sample_data_schema = '/__api_v2/datasets/{id}/sample_data'
     v2_sample_data_file = '/__api_v2/datasets/{id}/sample_data/file'
     v2_schema_instance_version = '/__api_v2/datasets/{id}/dictionaries/{version}'
+    v2_unstructured_document = '/__api_v2/datasets/{id}/documents'
 
     # schemas_many = '/__api/datasets/{id}/schemas/'
     # schema_instance = '/__api/datasets/{id}/schema/'
@@ -80,5 +81,7 @@ class sam_urls:
 
 class identity_urls:
     identity_token = '/api/identity/v2/auth/token'
+    identity_postbox = '/api/identity/v1/postbox_login'
+    identity_poll = '/api/identity/v2/auth/postbox'
     org_by_id = '/api/identity/v2/organisations/{id}'
     orgs_visible_to_user = '/api/identity/v2/organisations/visible'
\ No newline at end of file
