@@ -2,7 +2,6 @@
 # Copyright (C) 2020 IHS Markit.
 # All Rights Reserved
 #
-#import pyshorteners
 import base64
 import datetime
 import os
@@ -20,7 +19,6 @@ import logging
 import socket
 from http.cookiejar import CookiePolicy
 
-# import webview
 from wrapt import ObjectProxy
 from http import HTTPStatus
 from urllib.parse import urljoin, urlparse, parse_qs
@@ -31,8 +29,8 @@ from dli.client.adapters import DLIBearerAuthAdapter, DLIAccountsV1Adapter, \
     DLIInterfaceV1Adapter, DLISamAdapter
 from dli.client.components.urls import sam_urls, identity_urls
 from dli.client.environments import _Environment
+from dli.client.model_descriptor import ModelDescriptor
 from dli.models.organisation_model import OrganisationModel
-from dli.siren import siren_to_entity
 from dli.client.components.auto_reg_metadata import AutoRegMetadata
 from dli.client.components.datafile import Datafile
 from dli.client.components.dataset import Dataset, Dictionary
@@ -47,6 +45,8 @@ from dli.client.exceptions import (
     DatalakePayloadTooLargeException, TimeoutException
 )
 from dli.models.paginator import Paginator
+from dli.models.structured_dataset_model import StructuredDatasetModel
+from dli.models.unstructured_dataset_model import UnstructuredDatasetModel
 from dli.modules.dataset_module import DatasetModule
 from dli.modules.package_module import PackageModule
 from dli.models.dictionary_model import DictionaryModel
@@ -54,41 +54,12 @@ from dli.models.file_model import FileModel
 from dli.models.instance_model import InstanceModel, \
     InstancesCollection as InstancesCollection_
 from dli.models.package_model import PackageModel
-from dli.models.dataset_model import DatasetModel
+from dli.models.dataset_factory import DatasetFactory
 from dli.siren import PatchedSirenBuilder
-
+from dli.boto_authenticator import BotoAuthenticator
 
 trace_logger = logging.getLogger('trace_logger')
 
-
-class ModelDescriptor:
-    """
-    This class is responsible for extending the base type passed
-    into the __init__ method with the instance of DliClient it has
-    been created within, following the descriptor pattern.
-
-    What this means practicably, is that under _client attribute of the 'new'
-    type (class instance) there is a backreference to the DliClient,
-    which then permits the type to access the shared session object of DliClient,
-    rather than having to pass the session into each instance.
-
-    Using an instance instantiated from the base type will not have the
-    _client attribute available.
-    """
-
-    def __init__(self, model_cls=None):
-        self.model_cls = model_cls
-
-    def __get__(self, instance, owner):
-        """Returns a model thats bound to the client instance"""
-        return type(
-            self.model_cls.__name__, (self.model_cls, ),
-            {
-                '_client': instance
-            }
-        )
-
-
 class DliClient(Accounts, AutoRegMetadata,
                 Datafile, Dataset, Dictionary,
                 Me, Package):
@@ -97,7 +68,9 @@ class DliClient(Accounts, AutoRegMetadata,
     manipulating packages, datasets and datafiles.
     """
 
-    Dataset = ModelDescriptor(DatasetModel)
+    DatasetFactory = ModelDescriptor(DatasetFactory)
+    Structured = ModelDescriptor(StructuredDatasetModel)
+    Unstructured = ModelDescriptor(UnstructuredDatasetModel)
     Instance = ModelDescriptor(InstanceModel)
     _InstancesCollection = ModelDescriptor(InstancesCollection_)
     _Pagination = ModelDescriptor(Paginator)
@@ -122,7 +95,7 @@ class DliClient(Accounts, AutoRegMetadata,
         self.use_keyring = use_keyring
         self.logger = logging.getLogger(__name__)
 
-        self.logger.info(
+        self.logger.debug(
             'Starting SDK session',
             extra={
                'catalogue': self._environment.catalogue,
@@ -146,6 +119,8 @@ class DliClient(Accounts, AutoRegMetadata,
                 PendingDeprecationWarning
             )
 
+        self._boto_authenticator = None
+
 
     def _new_session(self):
         session = Session(
@@ -166,6 +141,28 @@ class DliClient(Accounts, AutoRegMetadata,
             self._session = self._new_session()
         return self._session
 
+    @property
+    def aws_authenticator(self):
+        """
+        Worker object that can be called with:
+
+        >>> client.aws_authenticator.start()
+
+        In order to sync the ~/.aws/credentials file with
+        the current user. Can be explicitly stopped via:
+
+        >>> client.aws_authenticator.stop()
+
+        Will simply shutdown when the DLI exits.
+        """
+        if (
+            not self._boto_authenticator or
+            not self._boto_authenticator.is_alive()
+        ):
+            self._boto_authenticator = BotoAuthenticator(self)
+
+        return self._boto_authenticator
+
 
 class Session(requests.Session):
 
@@ -266,14 +263,14 @@ class Session(requests.Session):
                                     self._environment.catalogue + f"-{ix}"
                                 )
                     except PasswordDeleteError as e:
-                        self.logger.info("No such password")
+                        self.logger.debug("No such password")
                     finally:
                         reloaded = None
             except Exception as e:
                 raise e
 
         if reloaded:
-            self.logger.info(f"Using vault JWT "
+            self.logger.debug(f"Using vault JWT "
                              f"{__product__} "
                              f"{self._environment.catalogue}")
             self.auth_key = reloaded
@@ -312,13 +309,8 @@ class Session(requests.Session):
         headers['X-Request-ID'] = request_id
 
         try:
-            # Human readable print logs
-            trace_logger.info(
-                f'{method} Request to {url} with request_id: {request_id}'
-            )
-
             self.logger.debug(
-                'Request',
+                f'{method} Request to {url} with request_id: {request_id}',
                 extra={
                     'method': method,
                     'request': url,
@@ -485,7 +477,8 @@ class Session(requests.Session):
                     identity_urls.identity_token),
             data={
                 "client_id": self.access_id,
-                "subject_token": token
+                "subject_token": token,
+                "origin": 'SDK'
             },
             hooks={'response': self._response_hook},
         )
@@ -519,17 +512,36 @@ class Session(requests.Session):
         else:
             callback(0, postbox)
 
+        # Cloudfront caches the calls to this URL with a TTL of
+        # one minute. The result is that if the first response is a
+        # HTTP status 404 then it keeps that result in cache for one
+        # minute. Setting the headers to disable cache just didn't make
+        # a difference, but adding a pause before the first call did.
+        time.sleep(1)
+
         while True:
             try:
                 query = self.get(
                     f"{self._environment.catalogue}"
                     f"{identity_urls.identity_poll}"
-                    f"?postbox={postbox}")
+                    f"?postbox={postbox}",
+                )
 
                 if query.ok:
                     str_jwt = query.text
                     _jwt = str.encode(str_jwt)
                     break
+            except TimeoutException as e:
+                print(
+                    "Sorry, the connection timed out. Please try again in "
+                    "one minute. If this is your first time trying to connect "
+                    "and the problem continues then it is possible you have "
+                    "a firewall issue (please contact your IT team to "
+                    "check if a firewall rule needs to be added).\n\n"
+                    "Technical details:"
+                    f"{e.message}"
+                )
+                sys.exit(0)
 
             except DatalakeException as e:
                 # anti-pattern time - to be able to patch session appropriately
@@ -573,7 +585,6 @@ class Session(requests.Session):
                         logging.warning(str(e))
                 else:
                     logging.warning(str(e))
-        # import pdb; pdb.set_trace()
         return str_jwt
 
 
@@ -583,23 +594,6 @@ class Response(ObjectProxy):
         super(Response, self).__init__(wrapped, *args, **kwargs)
         self.builder = builder
 
-    def to_siren(self):
-        # Pypermedias terminology, not mine
-        python_object = self.builder._construct_entity(
-            self.json()
-        ).as_python_object()
-
-        # Keep the response availible
-        python_object._raw_response = self
-
-        return python_object
-
-    def to_many_siren(self, relation):
-        return [
-            siren_to_entity(c) for c in
-            self.to_siren().get_entities(rel=relation)
-        ]
-
 
 class BlockAll(CookiePolicy):
     return_ok = set_ok = domain_return_ok = path_return_ok = lambda self, *args, **kwargs: False
