@@ -7,9 +7,19 @@ from urllib.parse import urlparse, ParseResult
 
 class _Environment:
 
+    _catalogue_environment_name_map = {
+        'catalogue.datalake.ihsmarkit.com': 'prod',
+        'catalogue-testprod.datalake.ihsmarkit.com': 'testprod',
+        'catalogue-uat.datalake.ihsmarkit.com': 'uat',
+        'client-uat.datalake.ihsmarkit.com': 'uat2',
+        'catalogue-dev.udpmarkit.net': 'dev',
+        'catalogue-qa.udpmarkit.net': 'qa',
+        'catalogue-qa2.udpmarkit.net': 'qa2',
+    }
 
     _catalogue_accounts_environment_map = {
         'catalogue.datalake.ihsmarkit.com': 'catalogue.datalake.ihsmarkit.com',
+        'catalogue-testprod.datalake.ihsmarkit.com': 'catalogue-testprod.datalake.ihsmarkit.com',
         'catalogue-uat.datalake.ihsmarkit.com': 'catalogue-uat.datalake.ihsmarkit.com',
         'client-uat.datalake.ihsmarkit.com': 'client-uat.datalake.ihsmarkit.com',
         'catalogue-dev.udpmarkit.net': 'catalogue-dev.udpmarkit.net',
@@ -19,6 +29,7 @@ class _Environment:
 
     _catalogue_consumption_environment_map = {
         'catalogue.datalake.ihsmarkit.com': 'consumption.datalake.ihsmarkit.com',
+        'catalogue-testprod.datalake.ihsmarkit.com': 'consumption-testprod.datalake.ihsmarkit.com',
         'catalogue-uat.datalake.ihsmarkit.com': 'consumption-uat.datalake.ihsmarkit.com',
         'client-uat.datalake.ihsmarkit.com': 'consumption-uat2.datalake.ihsmarkit.com',
         'catalogue-dev.udpmarkit.net': 'consumption-dev.udpmarkit.net',
@@ -28,6 +39,7 @@ class _Environment:
 
     _catalogue_sam_environment_map = {
         'catalogue.datalake.ihsmarkit.com': 'sam.ihsmarkit.com',
+        'catalogue-testprod.datalake.ihsmarkit.com': 'sam.ihsmarkit.com',
         'catalogue-uat.datalake.ihsmarkit.com': 'sam.ihsmarkit.com',
         'client-uat.datalake.ihsmarkit.com': 'sam.ihsmarkit.com',
         'catalogue-qa.udpmarkit.net': 'sam.samexternal.net',
@@ -37,6 +49,7 @@ class _Environment:
 
     _catalogue_sam_client_map = {
         'catalogue.datalake.ihsmarkit.com': 'datalake-pkce-prod-q56PXZSTDQ',
+        'catalogue-testprod.datalake.ihsmarkit.com': 'datalake-pkce-prod-q56PXZSTDQ',
         'catalogue-uat.datalake.ihsmarkit.com': 'datalake-pkce-uat-RMrWmjPhql',
         'client-uat.datalake.ihsmarkit.com': 'datalake-pkce-uat-RMrWmjPhql',
         'catalogue-qa.udpmarkit.net': 'datalake-pkce-sqa-BSFwJUigI4',
@@ -46,6 +59,7 @@ class _Environment:
 
     _s3_proxy_environment_map = {
         'catalogue.datalake.ihsmarkit.com': 's3.datalake.ihsmarkit.com',
+        'catalogue-testprod.datalake.ihsmarkit.com': 's3-testprod.datalake.ihsmarkit.com',
         'catalogue-uat.datalake.ihsmarkit.com': 's3-uat.datalake.ihsmarkit.com',
         'client-uat.datalake.ihsmarkit.com': 's3-uat2.datalake.ihsmarkit.com',
         'catalogue-qa.udpmarkit.net': 's3-qa.udpmarkit.net',
@@ -98,3 +112,7 @@ class _Environment:
         self.s3_proxy = self._s3_proxy_environment_map.get(
             catalogue_parse_result.netloc
         )
+
+        self.environment_name = self._catalogue_environment_name_map.get(
+            catalogue_parse_result.netloc, 'unknown'
+        )
