@@ -3,6 +3,7 @@
 # All Rights Reserved
 #
 import os
+from distutils.version import StrictVersion
 import warnings
 import requests
 import logging
@@ -13,6 +14,7 @@ from dli import __version__
 
 
 logger = logging.getLogger(__name__)
+trace_logger = logging.getLogger('trace_logger')
 DEPRECATED_AGE = 1
 
 
@@ -20,28 +22,34 @@ def _set_pypi_url(package_name):
     return f"https://pypi.python.org/pypi/{package_name}/json"
 
 
+def _is_release(x):
+    return x.replace(".", "").isnumeric()
+
+
 def version_check(package_name):
     url = _set_pypi_url(package_name)
 
     try:
         data = requests.get(url).json()
-        versions = list(x for x in data["releases"].keys() if 'b' not in x)
-        versions = sorted(versions)
+        versions = list(x for x in data["releases"].keys() if _is_release(x))
+        versions.sort(key=StrictVersion)
         versions.reverse()
 
         offset = versions.index(__version__)
-
         if offset > DEPRECATED_AGE:
-            warnings.warn("You are using an old version of the SDK, please upgrade "
-                          "using `pip install dli --upgrade` "
+            warnings.warn("You are using an old version of the SDK, please "
+                          "upgrade using `pip install dli --upgrade` "
                           "before the SDK no longer functions as expected",
                           PendingDeprecationWarning)
 
     except requests.exceptions.SSLError as e:
         # Version check has been see to fail by Gilberto with an SSLError
         # when doing the handshake with pypi.
-        logger.warning(f'SSLError pypi version_check:',
-                       extra={'SSLError': e})
+        trace_logger.warning(
+            f'SSLError pypi version_check:',
+            extra={'SSLError': e}
+        )
+        pass
     except Exception:
         pass
 
@@ -88,6 +96,11 @@ def start_session(*args, **kwargs):
     """
     .. deprecated:: 1.8.3
 
+        1. `api_key`: please use the basic flow or client credentials.
+
+        2. Please switch to using `client.connect()` as we may remove this
+        in the future.
+
 
     Entry point for the Data Lake SDK, returns a client instance that
     can be used to consume or register datasets.
@@ -125,12 +138,24 @@ def start_session(*args, **kwargs):
         `api_key`: please use the basic flow or client credentials.
 
     """
-    warnings.warn(
-        'start_session is deprecated. To create a client: \n\n'
-        '\t\timport dli\n'
-        '\t\tdli.connect()\n',
-        DeprecationWarning
-    )
+
+    # We know that headless and Excel spreadsheets still use this call, and
+    # the users do not look at the deprecation message so
+    # we cannot remove. We are going to not reference this in out
+    # documentation so that new users do not use it. When we have all our
+    # new users using `connect` we can remove this.
+
+    # We know that headless and Excel spreadsheets still use this call, and
+    # the users do not look at the deprecation message so
+    # we cannot remove. We are going to not reference this in out
+    # documentation so that new users do not use it. When we have all our
+    # new users using `connect` we can remove this.
+
+    # We know that headless and Excel spreadsheets still use this call, and
+    # the users do not look at the deprecation message so
+    # we cannot remove. We are going to not reference this in out
+    # documentation so that new users do not use it. When we have all our
+    # new users using `connect` we can remove this.
 
     return _start_session(*args, **kwargs)
 
