@@ -29,7 +29,7 @@ def ensure_count_is_valid(count):
 
 def print_model_metadata(model: AttributesDict):
     for (k, v) in vars(model).items():
-        if type(v) is str:
+        if k == "documentation" and type(v) is str:
             val = v[0:100].replace('\n', ' ').replace('\r', '') + "..." \
                 if len(v) > 100 else v
         else:
