@@ -30,8 +30,8 @@ class PackageModel(AttributesDict):
                 id=v1_response['properties']['packageId']
             )
         )
-
-        return cls(response.json())
+        json = response.json()
+        return cls(json)
 
     @classmethod
     def _from_v2_response_unsheathed(cls, response_json):
@@ -41,6 +41,10 @@ class PackageModel(AttributesDict):
         })
 
     def __init__(self, json):
+        # We have to declare the attribute `documentation` because it is
+        # referenced in the code of this class. This means that there will
+        # be an `documentation` attribute even when there is zero
+        # `documentation` attribute in the Catalogue response JSON.
         self.documentation = None
         self.__shape = None
 
@@ -52,8 +56,8 @@ class PackageModel(AttributesDict):
         super().__init__(id=json['data']['id'], **json['data']['attributes'])
         self._paginator = Paginator(
             package_urls.v2_package_datasets.format(id=self.id),
-            self._client.Dataset,
-            self._client.Dataset._from_v2_response_unsheathed
+            self._client.DatasetFactory,
+            self._client.DatasetFactory._from_v2_response_unsheathed
         )
 
     @property
@@ -111,7 +115,7 @@ class PackageModel(AttributesDict):
         split_description = "\n".join(textwrap.wrap(self.description, 80))
         split_keywords = "\n".join(self.keywords or [])
 
-        # documentation isnt guaranteed to be available
+        # documentation is not guaranteed to be available
         split_documentation = 'No documentation available.'
         if self.documentation is not None:
             split_documentation = "\n".join(textwrap.wrap(self.documentation, 80))
@@ -122,8 +126,7 @@ class PackageModel(AttributesDict):
         return f"\nPACKAGE \"{self.name}\" " \
                f"(Contains: {self.shape} datasets)\n" \
                f">> ID: {self.id} \n" \
-               f">> Sensitivity: {self.data_sensitivity} " \
-               f"/ Accessible: {self.has_access}\n" \
+               f">> Accessible: {self.has_access}\n" \
                f"\n" \
                f"{split_description}\n" \
                f"Documentation: {split_documentation}\n\n" \
