@@ -8,8 +8,10 @@ from dli.client.exceptions import CatalogueEntityNotFoundException
 class Client(DliClient):
     def __init__(self):
         self._session = MagicMock()
+        self.strict = False
         self._environment = MagicMock()
         self._environment.accounts = 'https://local.test/'
+        self.logger = MagicMock()
 
     @property
     def session(self):
@@ -54,6 +56,9 @@ class TestAccounts:
         assert account.id == 'test'
 
     def test_get_account_no_results(self, client):
+        account_name = 'CARM'
         client.session.get().json.return_value = {'data': []}
-        with pytest.raises(CatalogueEntityNotFoundException):
-            client.get_account_by_name('CARM')
+        assert client.get_account_by_name(account_name) is None
+        client.logger.warning.assert_called_once_with(
+            f'Account with name {account_name} not found'
+        )
