@@ -148,7 +148,7 @@ def csv_dataset_builder(package):
         package_id=package.id,
         name='dataset-files-test-' + random_name(),
         description="My dataset description",
-        content_type="Pricing",
+        content_type="Structured",
         data_format='CSV',
         publishing_frequency="Weekly",
         taxonomy=[]
