@@ -78,10 +78,11 @@ class TestDataset:
             client.get_dataset(dataset_short_code='timeout_dataset')
 
     def test_dataset_instances_is_iterable(self, client):
-        dataset = client.Dataset._from_v2_response({
+        dataset = client.DatasetFactory._from_v2_response({
             'data': {
                 'id': '1234',
                 'attributes': {
+                    'content_type': 'Structured',
                     'location': {},
                 }
             }
@@ -92,10 +93,11 @@ class TestDataset:
 
     def test_dataset_download_refers_to_latest_instance(self, client):
         path = './destination_path'
-        dataset = client.Dataset._from_v2_response({
+        dataset = client.DatasetFactory._from_v2_response({
             'data': {
                 'id': '1234',
                 'attributes': {
+                    'content_type': 'Structured',
                     'location': {},
                 }
             }
@@ -131,10 +133,11 @@ class TestDataset:
                 }]
             },
         ]
-        dataset = client.Dataset._from_v2_response({
+        dataset = client.DatasetFactory._from_v2_response({
             'data': {
                 'id': '1234',
                 'attributes': {
+                    'content_type': 'Structured',
                     'location': {},
                 }
             }
@@ -165,10 +168,11 @@ class TestDataset:
                 }]
             },
         ]
-        dataset = client.Dataset._from_v2_response({
+        dataset = client.DatasetFactory._from_v2_response({
             'data': {
                 'id': '1234',
                 'attributes': {
+                    'content_type': 'Structured',
                     'location': {},
                 }
             }
@@ -199,10 +203,11 @@ class TestDataset:
             boto_mock
         )
 
-        dataset = client.Dataset._from_v2_response({
+        dataset = client.DatasetFactory._from_v2_response({
             'data': {
                 'id': '1234',
                 'attributes': {
+                    'content_type': 'Structured',
                     'location': {},
                     'organisation_short_code': 'abc',
                     'short_code': 'abc',
@@ -233,10 +238,11 @@ class TestDataset:
         boto_mock = MagicMock()
         monkeypatch.setattr('dli.aws.Session', boto_mock)
 
-        dataset = client.Dataset._from_v2_response({
+        dataset = client.DatasetFactory._from_v2_response({
             'data': {
                 'id': '1234',
                 'attributes': {
+                    'content_type': 'Structured',
                     'location': {},
                     'organisation_short_code': 'abc',
                     'short_code': 'abc',
@@ -268,7 +274,7 @@ class TestDataset:
             dictionary_request_v2, fields_request_v2
         ]
 
-        dataset = test_client.Dataset._from_v2_response(dataset_request_v2)
+        dataset = test_client.DatasetFactory._from_v2_response(dataset_request_v2)
 
         def redirect(fun):
             with io.StringIO() as buf, redirect_stdout(buf):
@@ -517,10 +523,11 @@ class TestInstanceDataframe:
 
     @pytest.fixture
     def dataset(self, client):
-        return client.Dataset._from_v2_response({
+        return client.DatasetFactory._from_v2_response({
             'data': {
                 'id': '1234',
                 'attributes': {
+                    'content_type': 'Structured',
                     'location': {},
                     'has_access': True,
                     'short_code': 'some-short-code',
@@ -569,10 +576,11 @@ class TestInstanceDataframe:
         }
 
     def test_dataset_partitions(self, client, partitions):
-        dataset = client.Dataset._from_v2_response({
+        dataset = client.DatasetFactory._from_v2_response({
             'data': {
                 'id': '1234',
                 'attributes': {
+                    'content_type': 'Structured',
                     'location': {},
                 }
             }
@@ -583,6 +591,7 @@ class TestInstanceDataframe:
             'data': {
                 'id': '1234',
                 'attributes': {
+                    'content_type': 'Structured',
                     'location': {},
                 }
             }
@@ -591,9 +600,6 @@ class TestInstanceDataframe:
         msg = dataset.partitions()
         assert(msg == partitions["data"]["attributes"]["partitions"])
 
-        msg = client.get_dataset_partitions(id=dataset.id)
-        assert(msg == partitions["data"]["attributes"]["partitions"])
-
     def test_dataframe_handle_errors(self, arrow_ipc_stream,
                                      dataset):
         test_dataframe, stream = arrow_ipc_stream
