@@ -61,7 +61,6 @@ def test(session, pip_version):
         '4': test_requirements_offset_scenarios,
         '5': test_requirements_offset_scenarios,
         '6': test_requirements_offset_scenarios,
-        '7': test_requirements_offset_scenarios,
     }
     scenario = os.environ.get('NOX_SCENARIO')
     print('NOX_SCENARIO=', scenario)
@@ -116,6 +115,10 @@ class RequirementsModifier:
             'keyring': '17.1.1',
             'pyhumps': '0.5.1',
             'python-json-logger': '0.1.10',
+            # IPV6_ADDRZ_RE should be available in urllib3 1.25.4 forward
+            # which is the lowest version of the library botocore supports.
+            # https://github.com/boto/botocore/issues/2186#issuecomment-712449171
+            'urllib3': '1.25.4',
         }
 
         # package==version
@@ -123,7 +126,7 @@ class RequirementsModifier:
 
         # package!=version
         self.version_omit = {
-            'pyarrow': '0.13.0'
+            'pyarrow': '0.13.0',
         }
 
     def set_requirement_details(self):
