@@ -19,7 +19,7 @@ from dli import __version__, __product__
 from dli.client.components.urls import identity_urls
 from dli.client.dli_client import Session, DliClient
 from dli.client.environments import _Environment
-from dli.client.session import start_session
+from dli.client.session import _start_session
 from dli.client import session
 from dli.client.exceptions import (
     DatalakeException,
@@ -224,7 +224,7 @@ def mock_create_env_user(monkeypatch):
 def test_credentials_no_api_key(monkeypatch, mock_create_env_user, recwarn):
     # test flow when u/p set and no api key set
     monkeypatch.setattr(DliClient, '_new_session', lambda x: x)
-    dl = start_session()
+    dl = _start_session()
     assert(issubclass(type(dl), DliClient))
     assert(dl.secret_key is not None and dl.access_id is not None)
 
@@ -241,7 +241,7 @@ def test_api_key_deprecation_warning(recwarn, monkeypatch):
     # test flow when u/p set and api key set
     # api key should override
     monkeypatch.setattr(DliClient, '_new_session', MagicMock())
-    dl = start_session(api_key="Test")
+    dl = _start_session(api_key="Test")
     assert(issubclass(type(dl), DliClient))
     assert "`api_key` will be deprecated in the future" \
            in ",".join([str(x.message) for x in recwarn.list])
@@ -252,7 +252,7 @@ def test_credentials_and_api_key(mock_create_env_user, monkeypatch):
     # test flow when u/p set and api key set
     # api key should override
     monkeypatch.setattr(DliClient, '_new_session',  MagicMock())
-    dl = start_session(api_key="Test")
+    dl = _start_session(api_key="Test")
     assert (dl.secret_key is not None and dl.access_id is None)
 
 
@@ -266,7 +266,7 @@ def test_api_session(mock_create_env_user, mock_session):
 def test_credentials_and_no_api_key(mock_create_env_user, monkeypatch, caplog):
     # test flow when no credentials and api key set
     monkeypatch.setattr(session, "get_client", lambda: UnitTestClientMock)
-    dl = start_session()
+    dl = _start_session()
     for x in caplog.records:
         assert("old" not in x.message)
 
@@ -274,7 +274,7 @@ def test_credentials_and_no_api_key(mock_create_env_user, monkeypatch, caplog):
 def test_no_credentials_and_api_key(mock_del_env_user, monkeypatch, caplog):
     # test flow when no credentials and api key set
     monkeypatch.setattr(session, "get_client", lambda: UnitTestClientMock)
-    dl = start_session(api_key="Test")
+    dl = _start_session(api_key="Test")
     assert (dl.secret_key is not None and dl.access_id is None)
     for x in caplog.records:
         assert("new" not in x.message)
@@ -284,7 +284,7 @@ def test_api_key_auth(mock_del_env_user, monkeypatch):
     # test old auth process (_get_auth_key())
     api_response = valid_token
     monkeypatch.setattr(session, "get_client", lambda: UnitTestClientMockWithAuth)
-    dl = start_session(api_key="API")
+    dl = _start_session(api_key="API")
     dl._session.post = MagicMock()
     dl._session.post.return_value.text = api_response
 
@@ -302,7 +302,7 @@ def test_credentials_auth(mock_create_env_user, monkeypatch):
         "token_type": "Bearer", "expires_in": 3599}
 
     monkeypatch.setattr(session, "get_client", lambda: UnitTestClientMockWithAuth)
-    dl = start_session()
+    dl = _start_session()
     dl._session.post = MagicMock()
     dl._session.post.return_value.json.side_effect = [
         sam_response, catalogue_response
@@ -519,7 +519,7 @@ def test_set_JWT_keyring_web_auth_key(monkeypatch):
 def test_web_flow(clear_keyring, mock_del_env_user, monkeypatch):
 
     monkeypatch.setattr(session, "get_client", lambda: UnitTestClientMockNoPrompt)
-    dl = start_session(root_url="https://catalogue-dev.udpmarkit.net")
+    dl = _start_session(root_url="https://catalogue-dev.udpmarkit.net")
 
     # this is what get_web_auth_key is otherwise doing,
     # but we need to unblock to allow selenium to operate.
@@ -555,7 +555,7 @@ def test_credentials_on_catalogue(clear_keyring, real_client):
 def test_webflow_on_catalogue(monkeypatch, real_client):
 
     monkeypatch.setattr(session, "get_client", lambda: UnitTestClientMockNoPrompt)
-    dl = start_session(root_url="https://catalogue-dev.udpmarkit.net")
+    dl = _start_session(root_url="https://catalogue-dev.udpmarkit.net")
 
     # this is what get_web_auth_key is otherwise doing,
     # but we need to unblock to allow selenium to operate.
@@ -577,10 +577,10 @@ def test_no_system_keyring_installed(monkeypatch):
     try:
         from keyring.errors import NoKeyringError
         with pytest.raises(NoKeyringError):
-            dl = start_session(root_url="https://catalogue-dev.udpmarkit.net")
+            dl = _start_session(root_url="https://catalogue-dev.udpmarkit.net")
     except ImportError:
         with pytest.raises(RuntimeError):
-            dl = start_session(root_url="https://catalogue-dev.udpmarkit.net")
+            dl = _start_session(root_url="https://catalogue-dev.udpmarkit.net")
 
 
 def test_no_system_keyring_ack(monkeypatch, capsys):
@@ -595,10 +595,10 @@ def test_no_system_keyring_ack(monkeypatch, capsys):
     monkeypatch.setattr("dli.client.dli_client.Session._get_web_auth_key.__defaults__",
                         ( (lambda port, pb: t(pb)), ))
     monkeypatch.setattr(
-        "dli.client.dli_client.Session.get",  (lambda port, pb: a )
+        "dli.client.dli_client.Session.get",  (lambda port, pb: a)
     )
 
-    dl = start_session(root_url="https://catalogue-dev.udpmarkit.net")
+    dl = _start_session(root_url="https://catalogue-dev.udpmarkit.net")
 
 
     captured = capsys.readouterr()
